==> pg_bulkload-3.0.1.tar.gz: pg_bulkload-3.0.1/bin/sql/load_parallel.sql <==
\set BEFORE_NSHM `ipcs -m | grep -c [0-9]`
TRUNCATE customer;

\! pg_bulkload -d contrib_regression data/csv1.ctl -o"delimiter=|" -i data/data1.csv -o "WRITER=PARALLEL" -l results/parallel1.log -P results/parallel1.prs -u results/parallel1.dup -o "PARSE_ERRORS=50"
\! awk -f data/adjust.awk results/parallel1.log

SET enable_seqscan = on;
SET enable_indexscan = off;
SET enable_bitmapscan = off;
SELECT * FROM customer ORDER BY c_id;

SET enable_seqscan = off;
SET enable_indexscan = on;
SET enable_bitmapscan = off;
SELECT * FROM customer ORDER BY c_id;

\! pg_bulkload -d contrib_regression data/csv1.ctl -i data/data2.csv -o "WRITER=PARALLEL" -l results/parallel2.log -P results/parallel2.prs -u results/parallel2.dup -o "PARSE_ERRORS=50"
\! awk -f data/adjust.awk results/parallel2.log

SET enable_seqscan = on;
SET enable_indexscan = off;
SET enable_bitmapscan = off;
SELECT * FROM customer ORDER BY c_id;

SET enable_seqscan = off;
SET enable_indexscan = on;
SET enable_bitmapscan = off;
SELECT * FROM customer ORDER BY c_id;

\! pg_bulkload -d contrib_regression data/csv1.ctl -i data/data2.csv -o "WRITER=PARALLEL" -o "DUPLICATE_ERRORS=50" -l results/parallel3.log -P results/parallel3.prs -u results/parallel3.dup -o "PARSE_ERRORS=50"
\! awk -f data/adjust.awk results/parallel3.log

SET enable_seqscan = on;
SET enable_indexscan = off;
SET enable_bitmapscan = off;
SELECT * FROM customer ORDER BY c_id;

SET enable_seqscan = off;
SET enable_indexscan = on;
SET enable_bitmapscan = off;
SELECT * FROM customer ORDER BY c_id;

\! pg_bulkload -d contrib_regression data/csv1.ctl -i data/data2.csv -o "WRITER=PARALLEL" -o "PARSE_ERRORS=0" -l results/parallel4.log -P results/parallel4.prs -u results/parallel4.dup
\! awk -f data/adjust.awk results/parallel4.log

SET enable_seqscan = on;
SET enable_indexscan = off;
SET enable_bitmapscan = off;
SELECT * FROM customer ORDER BY c_id;

SET enable_seqscan = off;
SET enable_indexscan = on;
SET enable_bitmapscan = off;
SELECT * FROM customer ORDER BY c_id;

\set AFTER_NSHM `ipcs -m | grep -c [0-9]`
SELECT :AFTER_NSHM - :BEFORE_NSHM as "not destroy shared memorys";

==> pg_bulkload-3.1.0.tar.gz: pg_bulkload-3.1.0/bin/sql/load_parallel.sql <==
\set BEFORE_NSHM `ipcs -m | grep -c [0-9]`
TRUNCATE customer;

\! pg_bulkload -d contrib_regression data/csv1.ctl -o"delimiter=|" -i data/data1.csv -o "MULTI_PROCESS=YES" -l results/parallel1.log -P results/parallel1.prs -u results/parallel1.dup -o "PARSE_ERRORS=50"
\! awk -f data/adjust.awk results/parallel1.log

SET enable_seqscan = on;
SET enable_indexscan = off;
SET enable_bitmapscan = off;
SELECT * FROM customer ORDER BY c_id;

SET enable_seqscan = off;
SET enable_indexscan = on;
SET enable_bitmapscan = off;
SELECT * FROM customer ORDER BY c_id;

\! pg_bulkload -d contrib_regression data/csv1.ctl -i data/data2.csv -o "MULTI_PROCESS=YES" -l results/parallel2.log -P results/parallel2.prs -u results/parallel2.dup -o "PARSE_ERRORS=50"
\! awk -f data/adjust.awk results/parallel2.log

SET enable_seqscan = on;
SET enable_indexscan = off;
SET enable_bitmapscan = off;
SELECT * FROM customer ORDER BY c_id;

SET enable_seqscan = off;
SET enable_indexscan = on;
SET enable_bitmapscan = off;
SELECT * FROM customer ORDER BY c_id;

\! pg_bulkload -d contrib_regression data/csv1.ctl -i data/data2.csv -o "MULTI_PROCESS=YES" -o "WRITER=BUFFERED" -o "DUPLICATE_ERRORS=50" -l results/parallel3.log -P results/parallel3.prs -u results/parallel3.dup -o "PARSE_ERRORS=50"
\! awk -f data/adjust.awk results/parallel3.log

SET enable_seqscan = on;
SET enable_indexscan = off;
SET enable_bitmapscan = off;
SELECT * FROM customer ORDER BY c_id;

SET enable_seqscan = off;
SET enable_indexscan = on;
SET enable_bitmapscan = off;
SELECT * FROM customer ORDER BY c_id;

\! pg_bulkload -d contrib_regression data/csv1.ctl -i data/data2.csv -o "MULTI_PROCESS=YES" -o "WRITER=DIRECT" -o "PARSE_ERRORS=0" -l results/parallel4.log -P results/parallel4.prs -u results/parallel4.dup
\! awk -f data/adjust.awk results/parallel4.log

SET enable_seqscan = on;
SET enable_indexscan = off;
SET enable_bitmapscan = off;
SELECT * FROM customer ORDER BY c_id;

SET enable_seqscan = off;
SET enable_indexscan = on;
SET enable_bitmapscan = off;
SELECT * FROM customer ORDER BY c_id;

\set AFTER_NSHM `ipcs -m | grep -c [0-9]`
SELECT :AFTER_NSHM - :BEFORE_NSHM as "not destroy shared memorys";
